from setuptools import setup

setup(
    name='variable_protocols',
    version='1.1',
    packages=[''],
    package_data={'': ['py.typed']},
    url='https://github.com/cwhy/variable_protocols',
    license='GPL v3',
    author='cwhy',
    author_email='chenyu.nus@gmail.com',
    description='A protocol for machine learning variables'
)
